@@ -1,6 +1,6 @@
 use strict; use warnings;
 package pQuery;
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
 use pQuery::DOM;
 use Carp;
@@ -490,7 +490,7 @@ my $expr = {
 # The regular expressions that power the parsing engine
 my $parse = [
     # Match: [@value='test'], [@foo]
-    qr/^(\[) *@?([\w-]+) *([!*$^~=]*) *(\'?\"?)(.*?)\4 *\]/,
+    qr/^(\[)\s*\@?([\w-]+)\s*((?:[\!\*\$\^\~\|\=]?\=)?)\s*([\'\"]?)(.*?)(?:\4)\s*\]/,
 
     # Match: :contains('foo')
     qr/^(:)([\w-]+)\(\"?\'?(.*?(\(.*?\))?[^(]*?)\"?\'?\)/,
@@ -708,19 +708,36 @@ sub _filter {
                 my $a = $r->[$i];
                 my $z = $a->{($this->_props->{$m->[2]} || $m->[2])};
 
-                if (not defined $z or $m->[2] =~ /href|src|selected/) {
-                    $z = $this->attr($a, $m->[2]) || '';
+                if (not defined $z or $m->[2] =~ m/href|src|selected/) {
+                    $z = $a->attr($m->[2]);
                 }
 
                 if (
                     ((
-                        $type eq "" and $z or
-                        $type eq "=" and $z eq $m->[5] or
-                        $type eq "!=" and $z ne $m->[5] or
-                        $type eq "^=" and not index($z, $m->[5]) or
-                        $type eq '$=' and substr($z, (0-length($m->[5]))) or
-                        ($type eq "*=" or $type eq "~=") and
-                            index($z, $m->[5]) >= 0
+                        # Selects elements that have the specified attribute.
+                        ($type eq "" and defined $z) or
+                        # Selects elements that have the specified attribute with
+                        # a value exactly equal to a certain value.
+                        ($type eq "=" and defined $z and $z eq $m->[5]) or
+                        # Select elements that either dont have the specified attribute,
+                        # or do have the specified attribute but not with a certain value.
+                        ($type eq "!=" and (not defined $z or $z ne $m->[5])) or
+                        # Selects elements that have the specified attribute with a
+                        # value beginning exactly with a given string.
+                        ($type eq "^=" and defined $z and $z =~ /\A\Q$m->[5]\E/) or
+                        # Selects elements that have the specified attribute with
+                        # a value ending exactly with a given string (case sensitive)
+                        ($type eq '$=' and defined $z and $z =~ /\Q$m->[5]\E\z/) or
+                        # Selects elements that have the specified attribute with
+                        # a value containing the given substring.
+                        ($type eq "*=" and defined $z and $z =~ /\Q$m->[5]\E/) or
+                        # Selects elements that have the specified attribute with
+                        # a value containing a given word, delimited by spaces.
+                        ($type eq "~=" and defined $z and $z =~ /(?:\W|\A)\Q$m->[5]\E(?:\W|\z)/) or
+                        # Selects elements that have the specified attribute with
+                        # a value either equal to a given string or starting with
+                        # that string followed by a hyphen (-).
+                        ($type eq "|=" and defined $z and $z =~ /\A\Q$m->[5]\E(?:-|\z)/)
                     ) ? 1 : 0) ^ ($not ? 1 : 0)
                 ) { push @$tmp, $a }
             }
